@@ -9,8 +9,11 @@ import { NodePositionChange } from '@xyflow/react';
 import { OnConnect } from '@xyflow/react';
 import { OnEdgesChange } from '@xyflow/react';
 import { OnNodesChange } from '@xyflow/react';
+import * as React_2 from 'react';
 import { ReactFlowInstance } from '@xyflow/react';
+import { RJSFSchema } from '@rjsf/utils';
 import { StoreApi } from 'zustand';
+import { UiSchema } from '@rjsf/utils';
 import { UseBoundStore } from 'zustand';
 import { useReactFlow } from '@xyflow/react';
 
@@ -51,7 +54,7 @@ declare interface AllOf {
     allOf: SerializedType[];
 }
 
-declare type AnyDataType = JSONType | ArrayBufferLike;
+declare type AnyDataType = JSONType | ArrayBuffer | Blob;
 
 declare interface AnyOf {
     anyOf: SerializedType[];
@@ -59,6 +62,10 @@ declare interface AnyOf {
 
 export declare class ArrayBufferDataStructure extends DataStructure<ArrayBuffer, string> {
     private _objectUrl;
+    constructor({ data, mime }: {
+        data: BinarySource;
+        mime: string;
+    });
     get objectUrl(): string;
     dispose(): void;
     get value(): string;
@@ -152,10 +159,15 @@ declare interface BasicNodeType {
 
 declare type BasicOutputRendererType = (props: OutputRendererProps) => JSX.Element;
 
-export declare class CTypeStructure extends DataStructure<ArrayBufferLike, string | number | boolean | null> {
+declare type BinarySource = ArrayBufferLike | ArrayBufferView;
+
+export declare class CTypeStructure extends DataStructure<ArrayBuffer, string | number | boolean | null> {
     private _cType;
     private _value;
-    constructor({ data, mime }: DataStructureProps<ArrayBufferLike>);
+    constructor({ data, mime }: {
+        data: BinarySource;
+        mime: string;
+    });
     parse_value(): string | number | boolean | null;
     get value(): string | number | boolean | null;
     toString(): string;
@@ -403,6 +415,8 @@ declare interface ExternalWorkerInstance {
     name: string;
 }
 
+export declare const FuncNodes: (props: LimitedDeepPartial<FuncnodesReactFlowProps>) => React_2.JSX.Element;
+
 declare class FuncNodesReactFlow implements FuncNodesReactFlowZustandInterface {
     options: FuncnodesReactFlowProps;
     reactflowRef: HTMLDivElement | null;
@@ -473,7 +487,7 @@ declare interface FuncnodesReactFlowLocalState {
     funcnodescontainerRef: HTMLDivElement | null;
 }
 
-declare interface FuncnodesReactFlowProps {
+export declare interface FuncnodesReactFlowProps {
     id: string;
     debug: boolean;
     on_sync_complete?: (worker: FuncNodesWorker) => Promise<void>;
@@ -542,7 +556,7 @@ export declare type FuncNodesReactPlugin = VersionedFuncNodesReactPlugin<typeof
 
 export declare const FuncNodesRenderer: (id_or_element: string | HTMLElement, options?: Partial<FuncnodesReactFlowProps>) => void;
 
-declare class FuncNodesWorker {
+export declare class FuncNodesWorker {
     _zustand?: FuncNodesReactFlow;
     uuid: string;
     private _connectionhealthManager;
@@ -588,6 +602,7 @@ declare class FuncNodesWorker {
     stop(): Promise<void>;
     update_external_worker(worker_id: string, class_id: string, data: {
         name?: string;
+        config?: Record<string, any>;
     }): Promise<any>;
     export({ withFiles }: {
         withFiles: boolean;
@@ -647,6 +662,8 @@ declare type IOGetFullValue = () => Promise<any> | undefined;
 
 declare interface IORenderOptions extends BaseRenderOptions {
     set_default: boolean;
+    schema?: RJSFSchema;
+    uiSchema?: UiSchema;
 }
 
 declare interface IOStore {
@@ -687,15 +704,18 @@ declare type JSONMessage = ProgressStateMessage | ResultMessage | ErrorMessage |
 
 /**
  * Union type representing all supported data types for DataStructure instances.
- * Includes primitive types and ArrayBufferLike for binary data.
+ * Includes primitive types and binary data.
  */
 declare interface JSONObject {
     [key: string]: JSONType;
 }
 
-export declare class JSONStructure extends DataStructure<ArrayBufferLike, JSONType | undefined> {
+export declare class JSONStructure extends DataStructure<ArrayBuffer, JSONType | undefined> {
     private _json;
-    constructor({ data, mime }: DataStructureProps<any>);
+    constructor({ data, mime }: {
+        data: BinarySource;
+        mime: string;
+    });
     get value(): JSONType | undefined;
     static fromObject(obj: JSONType): JSONStructure;
     toString(): string;
@@ -1293,6 +1313,12 @@ declare type RFState = {
 
 declare type RFStore = UseBoundStore<StoreApi<RFState>>;
 
+declare type SchemaResponse = {
+    jsonSchema: RJSFSchema;
+    uiSchema?: UiSchema;
+    formData?: any;
+};
+
 declare interface SerializedIOType extends BasicIOType {
     value: IOValueType;
     fullvalue: IOValueType;
@@ -1335,9 +1361,12 @@ declare interface StateManagerManagerAPI {
     toast?: ToastDispatcher;
 }
 
-export declare class TextStructure extends DataStructure<ArrayBufferLike, string> {
+export declare class TextStructure extends DataStructure<ArrayBuffer, string> {
     private _value;
-    constructor({ data, mime }: DataStructureProps<ArrayBufferLike>);
+    constructor({ data, mime }: {
+        data: BinarySource;
+        mime: string;
+    });
     get value(): string;
     toString(): string;
 }
@@ -1499,7 +1528,7 @@ declare class WorkerCommunicationManager extends AbstractWorkerHandler {
         unique?: boolean;
     }): Promise<any>;
     receive(data: JSONMessage): Promise<any>;
-    recieve_bytes(headerObj: {
+    receive_bytes(headerObj: {
         [key: string]: string | undefined;
     }, bytes: Uint8Array): Promise<void>;
     onbytes(data: Uint8Array): Promise<void>;
@@ -1613,6 +1642,7 @@ declare interface WorkerHookProperties {
 }
 
 declare class WorkerLibraryManager extends AbstractWorkerHandler implements WorkerLibraryManagerAPI {
+    private _available_modules_cache;
     start(): void;
     stop(): void;
     add_external_worker({ module, cls_module, cls_name, }: {
@@ -1622,8 +1652,12 @@ declare class WorkerLibraryManager extends AbstractWorkerHandler implements Work
     }): Promise<any>;
     add_lib(lib: string, release: string): Promise<any>;
     remove_lib(lib: string): Promise<any>;
-    get_available_modules(): Promise<GroupedAvailableModules>;
+    get_available_modules({ wait_for_response, on_load, }: {
+        wait_for_response?: boolean;
+        on_load?: (modules: GroupedAvailableModules) => void;
+    }): Promise<GroupedAvailableModules>;
     remove_external_worker(worker_id: string, class_id: string): Promise<any>;
+    get_external_worker_config(worker_id: string, class_id: string): Promise<SchemaResponse>;
 }
 
 declare interface WorkerLibraryManagerAPI {
@@ -1634,8 +1668,12 @@ declare interface WorkerLibraryManagerAPI {
     }) => Promise<void>;
     add_lib: (lib: string, release: string) => Promise<void>;
     remove_lib: (lib: string) => Promise<void>;
-    get_available_modules: () => Promise<GroupedAvailableModules>;
+    get_available_modules: (args: {
+        wait_for_response?: boolean;
+        on_load?: (modules: GroupedAvailableModules) => void;
+    }) => Promise<GroupedAvailableModules>;
     remove_external_worker: (worker_id: string, class_id: string) => Promise<void>;
+    get_external_worker_config: (worker_id: string, class_id: string) => Promise<SchemaResponse>;
 }
 
 declare class WorkerManager {
@@ -1766,7 +1804,7 @@ declare interface WorkerNodeManagerAPI {
     get_remote_node_state: (nid: string) => Promise<void>;
 }
 
-declare interface WorkerProps {
+export declare interface WorkerProps {
     zustand?: FuncNodesReactFlow;
     uuid: string;
     on_error?: (error: string | Error) => void;
