@@ -7,7 +7,7 @@ import {
   renderHook,
 } from "@testing-library/react";
 import { describe, it, expect, vi, beforeEach, afterEach } from "vitest";
-import "@testing-library/jest-dom";
+import "@testing-library/jest-dom/vitest";
 
 import {
   KeyPressProvider,
